# Libket

Rust Quantum Programming library and Runtime library for the Ket programming language.

-----------

This project is part of the Ket Quantum Programming, see the documentation for more information https://quantumket.org.